Distru package
===============
This is a simple project that is used to grasp how to publish
Python packages on PyPI. This package is used to generate or read data
from a specific distribution and make some functionality or visualize it.

Installing
============
    pip install distru

Project description
===================
- This package works so far with two distributions, normal and binomial distribution.
- Package by default will generate random data from parameters you pass it or default parameters.
- Can read data from a file and the package will calculate its attributes automatically.
- Add two distributions of the same type together.
- Calculate some functions like PDF or PMF.
- Visualize distributions.

